import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { AppBreadcrumbService } from 'src/app/app.breadcrumb.service';
import { Candidate } from 'src/app/shared/models/candidate';
import { CandidateService } from 'src/app/shared/services/candidate.service';

@Component({
  selector: 'app-candidat-detail',
  templateUrl: './candidat-detail.component.html',
  styleUrls: ['./candidat-detail.component.scss']
})

export class CandidatDetailComponent implements OnInit {

  _candidat: Candidate = new Candidate() ;
  paramId: string;
  detailForm: FormGroup;
  submitted = false;

  constructor(private breadcrumbService: AppBreadcrumbService,private http: HttpClient, private candidateService: CandidateService, 
    private route: ActivatedRoute,private formBuilder: FormBuilder) {
    this.breadcrumbService.setItems([
      { label: 'Candidat' },
      { label: 'Detail' }
    ]);
  }

  ngOnInit(): void {
    this.getParamId();
    this.getCandidatById();
    this.currentDataForm();
  }

  private getCandidatById() {
    this.candidateService.candidatGetById(this.paramId)
      .subscribe(
        data => {
          this._candidat = data;
          console.log(data);
        },
        error => {
          console.log(error);
        });
  }

  private getParamId() {
    this.route.paramMap.subscribe(params => {
      if (params.get('candidatId')) {
        this.paramId = params.get('candidatId');
      }
    });
  }

  private currentDataForm() {
    this.detailForm = this.formBuilder.group({
      firstName: [this._candidat.firstName, Validators.required],
      lastName: [this._candidat.lastName, Validators.required]
    });
  }
  
  onSubmit() {
    this.submitted = true;
    if (this.detailForm.invalid) {
      alert('Data Error!! :\n\n' + JSON.stringify(this.detailForm.value, null,4));
      return;
    }
  }

}
