import { HttpClient } from '@angular/common/http';
import { Component, Injectable, Input, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { ActivatedRoute, Resolve, Router } from '@angular/router';
import { ModalDismissReasons, NgbModal } from '@ng-bootstrap/ng-bootstrap';
import { BehaviorSubject, Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { AppBreadcrumbService } from 'src/app/app.breadcrumb.service';
import { Candidate } from 'src/app/shared/models/candidate';
import { CandidateService } from 'src/app/shared/services/candidate.service';
import { candidatListService } from './candidat-list.service';

@Component({
  selector: 'app-candidat-list',
  templateUrl: './candidat-list.component.html',
  styleUrls: ['./candidat-list.component.scss']
})

export class CandidatListComponent implements OnInit {
  
   
    candidates: Observable<Candidate[]>;
    ftCandidates: Observable<Candidate[]>;
    candidatCP: Candidate;
    receiveCandidate = new BehaviorSubject<Candidate>(new Candidate());
    currentPage = 1;
    itemsPerPage = 5;
    pageSize: number;
    cp: number = 1;
    isSidebar: boolean = false;
    xy: any[];

    constructor(private breadcrumbService: AppBreadcrumbService,private http: HttpClient, 
      private candidatListService: candidatListService, private candidateService: CandidateService, private route: ActivatedRoute,private router: Router,
      private modalService: NgbModal,private formBuilder: FormBuilder) {
      this.breadcrumbService.setItems([
        { label: 'Candidats' },
        { label: 'List', routerLink: ['/candidat/candidat-list'] }
      ]);
  }

  ngOnInit() {
    this.candidates = this.candidatListService.getCandidats();
  }

  receiveSearchList(list: Observable<Candidate[]>) {
    this.candidates = list; 
   }

   receiveCandidat(candidatForm: FormGroup) {
     if(candidatForm.controls['id'].value){
       this.candidates.subscribe(e => 
        {
         var x = e.filter(f => f.id == candidatForm.controls['id'].value);
         x[0].id = candidatForm.controls['id'].value;
         x[0].firstName = candidatForm.controls['firstName'].value;
         x[0].lastName = candidatForm.controls['lastName'].value;
         
         this.candidates.subscribe(e => e.push(x[0])); 
        })
     }else{
      var c = new Candidate();
      this.candidates.subscribe(e => c.id = (1 + e.length).toString())
      c.lastName = candidatForm.controls['lastName'].value;
      c.firstName = candidatForm.controls['firstName'].value;
  /* 
      var exampleArray = [];
      exampleArray.push({'email' : c.lastName = candidatForm.controls['emailPro'].value , 'type': "profesionnal"});
      exampleArray.push({'email' : c.lastName = candidatForm.controls['emailPerso'].value , 'type': "personal"});
   */
      this.candidates.subscribe(e => e.push(c)); 
     }
    
   }
  showDetail(candidateId: string){
    var myurl = `${"/candidat/candidat-detail"}/${candidateId}`;
    this.router.navigateByUrl(myurl);
    
  }
  showNew(candidate: Candidate){
    if(candidate){
      this.isSidebar = true;
      this.receiveCandidate.next(candidate);
    }else{
      if(this.isSidebar){
        this.isSidebar = false;
      }else{
        this.isSidebar = true;
      }
    }
   
  }

  open(content) {
    this.modalService.open(content, {ariaLabelledBy: 'search-modal'});
  }

}
