import { HttpClient } from '@angular/common/http';
import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Observable } from 'rxjs';
import { AppBreadcrumbService } from 'src/app/app.breadcrumb.service';
import { Candidate } from 'src/app/shared/models/candidate';

@Component({
  selector: 'app-candidat-sidebar',
  templateUrl: './candidat-sidebar.component.html',
  styleUrls: ['./candidat-sidebar.component.scss']
})
export class CandidatSidebarComponent implements OnInit {
  createForm: FormGroup;
  isAddBtn: boolean = false;
  @Input() currentCandidat: Observable<Candidate>;
  @Output() public candidatResultEvent = new EventEmitter<FormGroup>();
  
  constructor(private breadcrumbService: AppBreadcrumbService,private http: HttpClient, private formBuilder: FormBuilder) {
    this.breadcrumbService.setItems([
      { label: 'Candidat' },
      { label: 'New' }
    ]);
  }

  ngOnInit(): void {
    if(this.currentCandidat && !this.isAddBtn){
      this.currentCandidat.subscribe(e => this.Form(e) );
    }else{
      this.Form(null);
    }
  }

  private Form(c: Candidate) {
    if(c){
      this.createForm = this.formBuilder.group({
        id : [c.id? c.id :""],
        firstName: [c.firstName? c.firstName :"", Validators.required],
        lastName: [c.lastName? c.lastName :"", Validators.required],
        emailPro: ["", Validators.email],
        emailPerso: ["", Validators.email]
      });
    }else{
      this.isAddBtn = true;
      this.createForm = this.formBuilder.group({
        firstName: ["", Validators.required],
        lastName: ["", Validators.required],
        emailPro: ["", Validators.email],
        emailPerso: ["", Validators.email]
      });
    }
  }
  
  onSubmit() {
    if (this.createForm.invalid) {
      alert('Data Error!! :\n\n' + JSON.stringify(this.createForm.value, null,4));
      return;
    }

    this.candidatResultEvent.emit(this.createForm);
  }
}
